/*
 * TestFileStatisticsException.cs
 *
 * File Statistics
 * Version: 1.0
 *
 * Copyright (c) 2005, TopCoder, Inc. All rights reserved
 *
 * Author: TCSDEVELOPER
 */

using System;
using NUnit.Framework;

namespace TopCoder.File.Statistics.Tests
{
    /// <summary>
    /// Unit tests for the <see cref="FileStatisticsException"/> class.
    /// </summary>
    [TestFixture]
    public class TestFileStatisticsException
    {
        /// <summary>
        /// A sample error message to use.
        /// </summary>
        private const string errMessage = "Error retrieving file statistics";

        /// <summary>
        /// A sample inner exception to use.
        /// </summary>
        private Exception inner = new Exception();

        /// <summary>
        /// Tests constructor(String) accuracy.
        /// </summary>
        [Test]
        public void TestConstructorString()
        {
            // instantiate with a sample error message
            FileStatisticsException e = new FileStatisticsException(errMessage);

            // assert error message is correct and inner exception is null
            Assert.AreEqual(errMessage, e.Message, "The error message is incorrect");
            Assert.IsNull(e.InnerException, "Inner exception should be null");
        }

        /// <summary>
        /// Tests constructor(String) with a null message.
        /// </summary>
        [Test]
        public void TestConstructorStringNull()
        {
            // instantiate with a null error message
            FileStatisticsException e = new FileStatisticsException(null);

            // assert error message is initizialied to default message and inner exception is null
            Assert.IsNotNull(e.Message, "The error message is the default message");
            Assert.IsNull(e.InnerException, "Inner exception should be null");
        }

        /// <summary>
        /// Tests constructor(String) with an empty message.
        /// </summary>
        [Test]
        public void TestConstructorStringEmpty()
        {
            // instantiate with an empty error message
            FileStatisticsException e = new FileStatisticsException("");

            // assert error message is empty and inner exception is null
            Assert.AreEqual("", e.Message, "The error message should be empty");
            Assert.IsNull(e.InnerException, "Inner exception should be null");
        }

        /// <summary>
        /// Tests constructor(String, Exception) accuracy.
        /// </summary>
        [Test]
        public void TestConstructorStringException()
        {
            // instantiate with a sample error message and an inner exception
            FileStatisticsException e = new FileStatisticsException(errMessage, inner);

            // assert error message and inner exception are correct
            Assert.AreEqual(errMessage, e.Message, "The error message is incorrect");
            Assert.AreSame(inner, e.InnerException, "Inner exception is different");
        }

        /// <summary>
        /// Tests constructor(String, Exception) with a null error message
        /// and an inner exception.
        /// </summary>
        [Test]
        public void TestConstructorStringExceptionNullMessage()
        {
            // instantiate with a null error message and an inner exception
            FileStatisticsException e = new FileStatisticsException(null, inner);

            // assert error message is initizialied to default message and inner exception is correct
            Assert.IsNotNull(e.Message, "The error message is the default message");
            Assert.AreSame(inner, e.InnerException, "Inner exception is different");
        }

        /// <summary>
        /// Tests constructor(String, Exception) with a sample error message
        /// and a null inner exception.
        /// </summary>
        [Test]
        public void TestConstructorStringExceptionNullInner()
        {
            // instantiate with a sample error message and a null inner exception
            FileStatisticsException e = new FileStatisticsException(errMessage, null);

            // assert error message is correct and inner exception is null
            Assert.AreEqual(errMessage, e.Message, "The error message is incorrect");
            Assert.IsNull(e.InnerException, "Inner exception should be null");
        }

        /// <summary>
        /// Tests constructor(String, Exception) with an empty error message
        /// and an inner exception.
        /// </summary>
        [Test]
        public void TestConstructorStringExceptionEmptyMessage()
        {
            // instantiate with an empty error message and an inner exception
            FileStatisticsException e = new FileStatisticsException("", inner);

            // assert error message is empty and inner exception is correct
            Assert.AreEqual("", e.Message, "The error message should be empty");
            Assert.AreSame(inner, e.InnerException, "Inner exception is different");
        }

        /// <summary>
        /// Tests <see cref="FileStatisticsException"/> inherits from <see cref="ApplicationException"/>.
        /// </summary>
        [Test]
        public void TestInheritance()
        {
            try
            {
                throw new FileStatisticsException(errMessage);
            }
            catch (Exception e)
            {
                // ok only if it's a direct subclass of ApplicationException
                Assert.AreEqual(typeof(ApplicationException), e.GetType().BaseType,
                    "FileStatisticsException is not a direct subclass of ApplicationException");
            }
        }
    }
}
