/*
Copyright (c)2005, TopCoder, Inc. All rights reserved
Author Cucu
*/

using NUnit.Framework;
using TopCoder.File.Statistics;
using System.IO;
using System.Collections;
using TopCoder.Util.ConfigurationManager;
using System.Text.RegularExpressions;
using TopCoder.File.Statistics.AccuracyTests;
using TopCoder.File.Statistics.Matcher;

namespace TopCoder.File.Statistics.AccuracyTests.Matcher
{
    /// <summary>
    /// </summary>
    [TestFixture]
    public class TypeNameMatcherAccuracyTest
    {              
        /// <summary>
        /// Set up for each test.
        /// </summary>
        [SetUp]
        public void SetUp()
        {
            TestHelper.LoadConfig(TestHelper.MAGIC_NUMBERS_CONFIG);
            TestHelper.LoadConfig(TestHelper.MATCHERS_CONFIG);
        }

        /// <summary>
        /// Tear down for each test.
        /// </summary>
        [TearDown]
        public void Teardown()
        {
            TestHelper.UnloadConfig(TestHelper.MATCHERS_CONFIG);
            TestHelper.UnloadConfig(TestHelper.MAGIC_NUMBERS_CONFIG);
        }

        /// <summary>
        /// Test the Match method against a single type
        /// </summary>
        [Test]
        public void MatchWithStringConstructor()
        {
            IFileMatcher matcher = new TypeNameMatcher("ZIP file");
            
            Assert.IsTrue(matcher.Match(new FileInfo(TestHelper.ZIP_FILE)),
                TestHelper.ZIP_FILE + " should match against 'ZIP FILE' type");

            Assert.IsFalse(matcher.Match(new FileInfo(TestHelper.TXT_FILE)),
                TestHelper.TXT_FILE + " should NOT match against 'ZIP FILE' type");

            Assert.IsFalse(matcher.Match(new FileInfo(TestHelper.CS_FILE)),
                TestHelper.CS_FILE + " should NOT match against 'ZIP FILE' type");
            
            Assert.IsFalse(matcher.Match(new FileInfo(TestHelper.DLL_FILE)),
                TestHelper.DLL_FILE + " should NOT match against 'ZIP FILE' type");

        }

        /// <summary>
        /// Test that the list constructor makes a copy of the list
        /// </summary>
        [Test]
        public void TestListConstructor() 
        {
            IList types  = new ArrayList();
            types.Add("ZIP file");
            
            IFileMatcher matcher = new TypeNameMatcher(types);
            
            // this shouldn't affect the matcher
            types.Add("Windows executable");
            
            Assert.IsFalse(matcher.Match(new FileInfo(TestHelper.DLL_FILE)), "constructor is not making a copy");
        }

        
        /// <summary>
        /// Test the Match method against many types, using the constructor that takes a list of types.
        /// </summary>
        [Test]
        public void MatchWithListConstructor()
        {
            IList types = new ArrayList();
            types.Add("ZIP file");
            types.Add("Windows executable");
            
            IFileMatcher matcher = new TypeNameMatcher(types);

            checkTypes(matcher);
        }

        /// <summary>
        /// Test the Match method against many types, using the constructor that reads from the configuration file.
        /// </summary>
        [Test]
        public void MatchWitConfigManagerConstructor()
        {
            IFileMatcher matcher = new TypeNameMatcher(TestHelper.FILE_STATISTICS_NAMESPACE, "type.matcher.");
            checkTypes(matcher);
        }

        /// <summary>
        /// Check that the matcher passed is matching well with the types: ZIP file and Windows executable
        /// </summary>
        /// <param name="matcher">the matcher to check.</param>
        private void checkTypes(IFileMatcher matcher) {
            Assert.IsTrue(matcher.Match(new FileInfo(TestHelper.ZIP_FILE)),
                TestHelper.ZIP_FILE + " should match against type list");

            Assert.IsTrue(matcher.Match(new FileInfo(TestHelper.DLL_FILE)),
                TestHelper.DLL_FILE + " should match against type list");

            Assert.IsFalse(matcher.Match(new FileInfo(TestHelper.TXT_FILE)),
                TestHelper.TXT_FILE + " should NOT match against type list");

            Assert.IsFalse(matcher.Match(new FileInfo(TestHelper.CS_FILE)),
                TestHelper.CS_FILE + " should NOT match against type list");
            

        }

         }    
}