using System;
using System.IO;

using TopCoder.Util.ConfigurationManager;

namespace TopCoder.File.Statistics.AccuracyTests
{
    /// <summary>
    /// Helper methods and constants for accuracy tests.
    /// </summary>
    internal class TestHelper
    {

        /// <summary>
        /// Configuration file for Magic Numbers component
        /// </summary>
        public const string MAGIC_NUMBERS_CONFIG = @"..\..\test_files\AccuracyTests\MagicNumber.xml";

        /// <summary>
        /// Namespace for this component
        /// </summary>
        public const string FILE_STATISTICS_NAMESPACE = "TopCoder.File.Statistics";

        /// <summary>
        /// Name of the configuration file used for tests of matchers.
        /// </summary>
        public const string MATCHERS_CONFIG = @"..\..\test_files\AccuracyTests\Matchers.xml";

        /// <summary>
        /// Name of the configuration file used for tests of Processors.
        /// </summary>
        public const string PROCESSOR_CONFIG = @"..\..\test_files\AccuracyTests\Processor.xml";

        /// <summary>
        /// Name of the configuration file used for tests of FileStatistics.
        /// </summary>
        public const string FILE_STATISTICS_CONFIG = @"..\..\test_files\AccuracyTests\FileStatistics.xml";

        /// <summary>
        /// Name of a txt file used for matching
        /// </summary>
        public const string TXT_FILE = @"..\..\test_files\AccuracyTests\files\textFile1.txt";

        /// <summary>
        /// Name of a txt file used for line counting
        /// </summary>
        public const string LYRIC_TXT_FILE = @"..\..\test_files\AccuracyTests\files\lyric.txt";

        /// <summary>
        /// Name of a txt file used for line counting
        /// </summary>
        public const string BIG_TXT_FILE = @"..\..\test_files\AccuracyTests\files\bigfile.txt";

        /// <summary>
        /// Name of a cs file used for matching and C Style line counting
        /// </summary>
        public const string CS_FILE = @"..\..\test_files\AccuracyTests\files\program.cs";
        
        /// <summary>
        /// Name of a java file used for C Style line counting
        /// </summary>
        public const string JAVA_FILE = @"..\..\test_files\AccuracyTests\files\HelloWorld.java";

        /// <summary>
        /// Name of a cpp file used for C Style line counting
        /// </summary>
        public const string CPP_FILE = @"..\..\test_files\AccuracyTests\files\AlphabetCount.cpp";

        /// <summary>
        /// Name of a cpp file used for C Style line counting
        /// </summary>
        public const string CPP_FILE_ANOTHER_DIR = @"..\..\test_files\AccuracyTests\files\another_dir\AlphabetCount.cpp";

        /// <summary>
        /// Name of a zip file used for matching
        /// </summary>
        public const string ZIP_FILE = @"..\..\test_files\AccuracyTests\files\binaryFile1.zip";

        /// <summary>
        /// Name of a dll file used for matching
        /// </summary>
        public const string DLL_FILE =@"..\..\test_files\AccuracyTests\files\binaryFile2.dll";


        /// <summary>
        /// Load the configuration from a file.
        /// </summary>
        ///
        /// <param name="fileName">file to load</param>
        public static void LoadConfig(string fileName)
        {
            ConfigManager.GetInstance().RemoveFile(fileName);
            ConfigManager.GetInstance().LoadFile(fileName);
        }

        /// <summary>
        /// Unloads a file from config manager.
        /// </summary>
        ///
        /// <param name="fileName">file to unload.</param>
        public static void UnloadConfig(string fileName)
        {
            ConfigManager.GetInstance().RemoveFile(fileName);
        }

        /// <summary>
        /// Saves a string to a file in "..\..\test_files\AccuracyTests\" for visual inspection
        /// </summary>
        public static void SaveToFile(string filename, string str) 
        {
            StreamWriter sw = new StreamWriter(@"..\..\test_files\AccuracyTests\" + filename);
            sw.Write(str);
            sw.Close();
        }

    }
}
