///
/// $(#)CStyleLineCounter.cs		Sep 6, 2005
/// 
/// Copyright (c) 2005, TopCoder Inc. All rights reserved.
/// </summary>

using System;
using System.IO;
using NUnit.Framework;

using TopCoder.File.Statistics.Matcher;
using TopCoder.File.Statistics.Processor.LineCounter;
using TopCoder.Util.ConfigurationManager;

namespace TopCoder.File.Statistics.FailureTests.Proccessor.LineCounter
{

	/// <summary>
    /// This test fixture contains the failure tests for <see cref="CStyleLineCounter"/> class.
    ///
    /// <author>MPhk</author>
    /// <version>1.0</version>
    /// <copyright>Copyright (C) 2005 TopCoder Inc., All Rights Reserved.</copyright>
    /// </summary>
    [TestFixture]
	public class CStyleLineCounterTests {
	
	    /// <summary>
	    /// The namespace for this test.
	    /// </summary>
	    private const string NAMESPACE = "TopCoder.File.Statistics.Processor.LineCounter.Failuretests";
	
	    /// <summary>
	    /// The config file for this test.
	    /// </summary>
	    private const string CONFIG_FILE = "../../test_files/failuretests/processor/config.xml";
	
	    /// <summary>
	    /// The the base path of the test files.
	    /// </summary>
	    private const string BASE_PATH = "../../test_files/failuretests/processor/";
	
	    /// <summary>
	    /// An CStyleLineCounter instance to test.
	    /// </summary>
	    private CStyleLineCounter counter = null;
	
	    /// <summary>
	    /// Load the configuration before testing.
	    /// </summary>
	    [SetUp]
	    protected void SetUp() {
	        // clear the namespace first
	        ConfigManager configManager = ConfigManager.GetInstance();
	        configManager.RemoveFile(CONFIG_FILE);
	        // load the configuration
	        configManager.LoadFile(CONFIG_FILE);
	        
	        counter = new CStyleLineCounter("Text", new ExtensionMatcher("txt"));
	    }
	
	    /// <summary>
	    /// Remove the configuration after testing.
	    /// </summary>
	    [TearDown]
	    protected void TearDown() {
	        ConfigManager configManager = ConfigManager.GetInstance();
	        configManager.RemoveFile(CONFIG_FILE);
	    }
	
	    /// <summary>
	    /// Checks whether the constructor CStyleLineCounter(String, FileMatcher) properly throws
	    /// ArgumentNullException for null argument.
	    /// </summary>
	    [Test, ExpectedException(typeof(ArgumentNullException))]
	    public void TestCStyleLineCounter1() {
            new CStyleLineCounter(null, new ExtensionMatcher("txt"));
	    }
	
	    /// <summary>
	    /// Checks whether the constructor CStyleLineCounter(String, FileMatcher) properly throws
	    /// ArgumentNullException for null argument.
	    /// </summary>
	    [Test, ExpectedException(typeof(ArgumentNullException))]
	    public void TestCStyleLineCounter2() {
	    	new CStyleLineCounter("alias", (IFileMatcher)null);
	    }
	
	    /// <summary>
	    /// Checks whether the constructor CStyleLineCounter(String, FileMatcher) properly throws
	    /// ArgumentException for empty String argument.
	    /// </summary>
	    [Test, ExpectedException(typeof(ArgumentException))]
	    public void TestCStyleLineCounter3() {
            new CStyleLineCounter(" ", new ExtensionMatcher("txt"));
	    }
	
	    /// <summary>
	    /// Checks whether the constructor CStyleLineCounter(string, string) properly throws
	    /// ArgumentNullException for null argument.
	    /// </summary>
	    [Test, ExpectedException(typeof(ArgumentNullException))]
	    public void TestCStyleLineCounter4() {
            new CStyleLineCounter(null, "prefix");
	    }
	    
	    /// <summary>
	    /// Checks whether the constructor CStyleLineCounter(string, string) properly throws
	    /// ArgumentException for empty argument.
	    /// </summary>
	    [Test, ExpectedException(typeof(ArgumentException))]
	    public void TestCStyleLineCounter5() {
            new CStyleLineCounter("", "prefix");
	    }
	    
	    /// <summary>
	    /// Checks whether the constructor CStyleLineCounter(string, string) properly throws
	    /// ArgumentNullException for null argument.
	    /// </summary>
	    [Test, ExpectedException(typeof(ArgumentNullException))]
	    public void TestCStyleLineCounter6() {
	    	new CStyleLineCounter("namespace", (string)null);
	    }
	
	    /// <summary>
	    /// Checks whether the constructor CStyleLineCounter(Property) properly throws
	    /// ConfigurationException for invalid property.
	    /// </summary>
	    [Test, ExpectedException(typeof(ConfigurationException))]
	    public void TestCStyleLineCounter7() {
            new CStyleLineCounter(NAMESPACE, "invalid1");
	    }
	
	    /// <summary>
	    /// Checks whether the constructor CStyleLineCounter(Property) properly throws
	    /// ConfigurationException for invalid property.
	    /// </summary>
	    [Test, ExpectedException(typeof(ConfigurationException))]
	    public void TestCStyleLineCounter8() {
            new CStyleLineCounter(NAMESPACE, "invalid2");
	    }
	
	    /// <summary>
	    /// Checks whether the constructor CStyleLineCounter(Property) properly throws
	    /// ConfigurationException for invalid property.
	    /// </summary>
	    [Test, ExpectedException(typeof(ConfigurationException))]
	    public void TestCStyleLineCounter9() {
            new CStyleLineCounter(NAMESPACE, "invalid3");
	    }
	
	    /// <summary>
	    /// Checks whether the constructor CStyleLineCounter(Property) properly throws
	    /// ConfigurationException for invalid property.
	    /// </summary>
	    [Test, ExpectedException(typeof(ConfigurationException))]
	    public void TestCStyleLineCounter10() {
            new CStyleLineCounter(NAMESPACE, "invalid5");
	    }
	
	    /// <summary>
	    /// Checks whether the constructor CStyleLineCounter(Property) properly throws
	    /// ConfigurationException for invalid property.
	    /// </summary>
	    [Test, ExpectedException(typeof(ConfigurationException))]
	    public void TestCStyleLineCounter11() {
            new CStyleLineCounter(NAMESPACE, "invalid6");
	    }
	
	    /// <summary>
	    /// Checks whether the constructor CStyleLineCounter(Property) properly throws
	    /// ConfigurationException for invalid property.
	    /// </summary>
	    [Test, ExpectedException(typeof(ConfigurationException))]
	    public void TestCStyleLineCounter12() {
            new CStyleLineCounter(NAMESPACE, "invalid7");
	    }
	
	    /// <summary>
	    /// Checks whether the constructor CStyleLineCounter(Property) properly throws
	    /// ConfigurationException for invalid property.
	    /// </summary>
	    [Test, ExpectedException(typeof(ConfigurationException))]
	    public void TestCStyleLineCounter13() {
            new CStyleLineCounter(NAMESPACE, "invalid8");
	    }
	
	    /// <summary>
	    /// Checks whether the constructor CStyleLineCounter(Property) properly throws
	    /// ConfigurationException for invalid property.
	    /// </summary>
	    [Test, ExpectedException(typeof(ConfigurationException))]
	    public void TestCStyleLineCounter14() {
            new CStyleLineCounter(NAMESPACE, "invalid9");
	    }
	
	    /// <summary>
	    /// Tests the process method with null argument. ArgumentNullException should be thrown.
	    /// </summary>
	    [Test, ExpectedException(typeof(ArgumentNullException))]
	    public void TestProcess1() {
            counter.Process(null);
	    }
	
	    /// <summary>
	    /// Tests the process method with a folder as argument. IOException should be thrown.
	    /// </summary>
	    [Test, ExpectedException(typeof(IOException))]
	    public void TestProcess2() {
	    	try {
            	counter.Process(new FileInfo(BASE_PATH));
            } catch (IOException) {
	    		throw new IOException();
	    	}
	    }
	
	    /// <summary>
	    /// Tests the process method with invalid argument. IOException should be thrown.
	    /// </summary>
	    [Test, ExpectedException(typeof(IOException))]
	    public void TestProcess3() {
	    	try {
            	counter.Process(new FileInfo(BASE_PATH + "/inexistent_file"));
            } catch (IOException) {
	    		throw new IOException();
	    	}
	    }
    }
}
