/*
 * TestMissingInitializationException.cs
 *
 * File Statistics
 * Version: 1.0
 *
 * Copyright (c) 2005, TopCoder, Inc. All rights reserved
 *
 * Author: TCSDEVELOPER
 */

using System;
using NUnit.Framework;

namespace TopCoder.File.Statistics.Tests
{
    /// <summary>
    /// Unit tests for the <see cref="MissingInitializationException"/> class.
    /// </summary>
    [TestFixture]
    public class TestMissingInitializationException
    {
        /// <summary>
        /// A sample error message to use.
        /// </summary>
        private const string errMessage = "Missing initialization";

        /// <summary>
        /// Tests constructor(String) accuracy.
        /// </summary>
        [Test]
        public void TestConstructorString()
        {
            // instantiate with a sample error message
            MissingInitializationException e = new MissingInitializationException(errMessage);

            // assert error message is correct and inner exception is null
            Assert.AreEqual(errMessage, e.Message, "The error message is incorrect");
            Assert.IsNull(e.InnerException, "Inner exception should be null");
        }

        /// <summary>
        /// Tests constructor(String) with a null message.
        /// </summary>
        [Test]
        public void TestConstructorStringNull()
        {
            // instantiate with a null error message
            MissingInitializationException e = new MissingInitializationException(null);

            // assert error message is initizialied to default message and inner exception is null
            Assert.IsNotNull(e.Message, "The error message is the default message");
            Assert.IsNull(e.InnerException, "Inner exception should be null");
        }

        /// <summary>
        /// Tests constructor(String) with an empty message.
        /// </summary>
        [Test]
        public void TestConstructorStringEmpty()
        {
            // instantiate with an empty error message
            MissingInitializationException e = new MissingInitializationException("");

            // assert error message is empty and inner exception is null
            Assert.AreEqual("", e.Message, "The error message should be empty");
            Assert.IsNull(e.InnerException, "Inner exception should be null");
        }

        /// <summary>
        /// Tests <see cref="MissingInitializationException"/> inherits from
        /// <see cref="ConfigurationException"/>.
        /// </summary>
        [Test]
        public void TestInheritance()
        {
            MissingInitializationException e = new MissingInitializationException(errMessage);

            // ok only if it's a direct subclass of FileStatisticsException
            Assert.AreEqual(typeof(ConfigurationException), e.GetType().BaseType,
                "MissingInitializationException is not a direct subclass of ConfigurationException");
        }
    }
}
